@@ -105,6 +105,7 @@ openstack_projects = [
     'keystone',
     'kolla',
     'kolla-ansible',
+    'magnum',
     'manila',
     'networking-sfc',
     'neutron-vpnaas',
@@ -113,4 +114,5 @@ openstack_projects = [
     'octavia',
     'oslotest',
     'swift',
+    'watcher',
 ]
