@@ -11,12 +11,15 @@ copy_logs() {
     rm ${LOG_DIR}/kolla_configs/config/ironic/ironic-agent.{kernel,initramfs}
     mkdir ${LOG_DIR}/system_configs/
     cp -rL /etc/{hostname,hosts,host.conf,resolv.conf,nsswitch.conf,docker,systemd} ${LOG_DIR}/system_configs/
+    # Remove /var/log/kolla link to not double the data uploaded
+    unlink /var/log/kolla
     cp -rvnL /var/log/* ${LOG_DIR}/system_logs/
 
 
     if [[ -x "$(command -v journalctl)" ]]; then
         journalctl --no-pager > ${LOG_DIR}/system_logs/syslog.txt
         journalctl --no-pager -u docker.service > ${LOG_DIR}/system_logs/docker.log
+        journalctl --no-pager -u containerd.service > ${LOG_DIR}/system_logs/containerd.log
     else
         cp /var/log/upstart/docker.log ${LOG_DIR}/system_logs/docker.log
     fi
@@ -77,14 +80,15 @@ copy_logs() {
     # docker related information
     (docker info && docker images && docker ps -a && docker network ls && docker inspect $(docker ps -aq)) > ${LOG_DIR}/system_logs/docker-info.txt
 
-    # ceph related logs
-    if [[ $(docker ps --filter name=ceph_mon --format "{{.Names}}") ]]; then
-        docker exec ceph_mon ceph --connect-timeout 5 -s > ${LOG_DIR}/kolla/ceph/ceph_s.txt
+    # ceph-ansible related logs
+    mkdir -p ${LOG_DIR}/ceph
+    for container in $(docker ps --filter name=ceph-mon --format "{{.Names}}"); do
+        docker exec ${container} ceph --connect-timeout 5 -s > ${LOG_DIR}/ceph/ceph_s.txt
         # NOTE(yoctozepto): osd df removed on purpose to avoid CI POST_FAILURE due to a possible hang:
         # as of ceph mimic it hangs when MON is operational but MGR not
         # its usefulness is mediocre and having POST_FAILUREs is bad
-        docker exec ceph_mon ceph --connect-timeout 5 osd tree > ${LOG_DIR}/kolla/ceph/ceph_osd_tree.txt
-    fi
+        docker exec ${container} ceph --connect-timeout 5 osd tree > ${LOG_DIR}/ceph/ceph_osd_tree.txt
+    done
 
     # bifrost related logs
     if [[ $(docker ps --filter name=bifrost_deploy --format "{{.Names}}") ]]; then
@@ -109,7 +113,7 @@ copy_logs() {
     fi
 
     for container in $(docker ps -a --format "{{.Names}}"); do
-        docker logs --tail all ${container} &> ${LOG_DIR}/docker_logs/${container}.txt
+        docker logs --timestamps --tail all ${container} &> ${LOG_DIR}/docker_logs/${container}.txt
     done
 
     # Rename files to .txt; this is so that when displayed via
@@ -123,6 +127,8 @@ copy_logs() {
     done
 
     chmod -R 777 ${LOG_DIR}
+
+    du -sm ${LOG_DIR}
 }
 
 copy_logs
