@@ -65,9 +65,9 @@ def genpwd(passwords_file, length, uuid_keys, ssh_keys, blank_keys,
 
     for k, v in passwords.items():
         if (k in ssh_keys and
-                (v is None
-                 or v.get('public_key') is None
-                 and v.get('private_key') is None)):
+                (v is None or
+                 v.get('public_key') is None and
+                 v.get('private_key') is None)):
             private_key, public_key = generate_RSA()
             passwords[k] = {
                 'private_key': private_key,
@@ -107,8 +107,7 @@ def main():
     passwords_file = os.path.expanduser(args.passwords)
 
     # These keys should be random uuids
-    uuid_keys = ['ceph_cluster_fsid',
-                 'rbd_secret_uuid',
+    uuid_keys = ['rbd_secret_uuid',
                  'cinder_rbd_secret_uuid',
                  'gnocchi_project_id',
                  'gnocchi_resource_id',
